@@ -31,7 +31,7 @@
 #include "mainwindow.h"
 
 #include "ui_main.h"
-#include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/core/pappsoexception.h>
 #include "../utils/utils.h"
 #include "output/xpip.h"
 
@@ -43,10 +43,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
   ui->setupUi(this);
   setWindowTitle(QString("%1 %2").arg(SOFTWARE_NAME).arg(i2MassChroQ_VERSION));
   setWindowIcon(QIcon(":/i2masschroq_icon/resources/i2MassChroQ_icon.svg"));
+  
 
 
   _p_app->setOrganizationName("PAPPSO");
-  _p_app->setOrganizationDomain("pappso.inra.fr");
+  _p_app->setOrganizationDomain("pappso.inrae.fr");
   _p_app->setApplicationName("i2masschroq");
   _p_app->setApplicationVersion(i2MassChroQ_VERSION);
 
@@ -62,8 +63,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
   _project_window = new ProjectWindow(this);
 
   ui->menu_export_files->setDisabled(true);
+  ui->actionSpectral_Count->setDisabled(true);
   ui->actionMassChroQ->setDisabled(true);
-  ui->menuMCQR->setDisabled(true);
+  ui->actionMCQR->setVisible(true);
   ui->centralwidget->layout()->addWidget(_project_window);
   _project_window->hide();
   ui->action_save_project->setDisabled(true);
@@ -78,6 +80,13 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
   qRegisterMetaType<AutomaticFilterParameters>("AutomaticFilterParameters");
   qRegisterMetaType<GroupingType>("GroupingType");
 
+
+  // ui->actionSpectral_Count->setVisible(false);
+#if EXPERIMENTAL_FEATURES_ON == 1
+  // ui->menuMCQR_dev->setVisible(false);
+  // ui->actionSpectral_Count->setVisible(true);
+#endif
+
 #if QT_VERSION >= 0x050000
   // Qt5 code
   connect(_p_load_results_dialog,
@@ -111,12 +120,32 @@ MainWindow::~MainWindow()
   delete _p_load_results_dialog;
   delete _p_export_spreadsheet_dialog;
   delete _p_waiting_message_dialog;
-  delete mp_mcqrParamAllQuantiDialog;
-  delete mp_mcqrRunView;
   if(_p_export_masschroq_dialog != nullptr)
     {
       delete _p_export_masschroq_dialog;
     }
+
+  if(mp_msstatsRun != nullptr)
+    {
+      mp_msstatsRun->close();
+      delete mp_msstatsRun;
+    }
+  if(mp_mcqrRun != nullptr)
+    {
+
+      mp_mcqrRun->close();
+      delete mp_mcqrRun;
+    }
+  if(mp_mcqrScRun != nullptr)
+    {
+      mp_mcqrScRun->close();
+      delete mp_mcqrScRun;
+    }
+  if(mp_sageRunDialog != nullptr)
+    {
+      mp_sageRunDialog->close();
+      delete mp_sageRunDialog;
+    }
   qDebug();
 }
 
@@ -144,6 +173,10 @@ MainWindow::stopWorkerThread()
 void
 MainWindow::closeEvent(QCloseEvent *event)
 {
+  if(mp_msstatsRun != nullptr)
+    {
+      mp_msstatsRun->close();
+    }
   if(_project_sp != nullptr)
     {
       if(_project_sp.get()->getProjectChangedStatus() == true)
@@ -271,7 +304,9 @@ MainWindow::doAcceptedExportSpreadsheetDialog()
           filename = QFileDialog::getSaveFileName(
             this,
             tr("Save ODS file"),
-            QString("%1/untitled.ods").arg(default_location),
+            QString("%1/%2.ods")
+              .arg(default_location)
+              .arg(_project_sp.get()->getProjectName()),
             tr("Open Document Spreadsheet (*.ods)"));
 
           settings.setValue("path/export_ods",
@@ -282,10 +317,34 @@ MainWindow::doAcceptedExportSpreadsheetDialog()
           filename = QFileDialog::getExistingDirectory(
             this, tr("Save TSV files"), QString("%1").arg(default_location));
 
-          QDir parent(filename);
-          parent.cdUp();
-          settings.setValue("path/export_ods", parent.canonicalPath());
-          qDebug() << parent.absolutePath();
+          if(!filename.isEmpty() && !filename.isNull())
+            {
+              QDir parent(filename);
+              settings.setValue("path/export_ods", parent.canonicalPath());
+              qDebug() << parent.absolutePath();
+
+              if(parent.mkdir(_project_sp.get()->getProjectName()))
+                {
+                  parent.cd(_project_sp.get()->getProjectName());
+                  filename = parent.canonicalPath();
+                }
+              else
+                {
+                  if(parent.cd(_project_sp.get()->getProjectName()))
+                    {
+                      throw pappso::PappsoException(
+                        QObject::tr(
+                          "Unable to write files : export directory %1 "
+                          "already exists")
+                          .arg(parent.canonicalPath()));
+                    }
+                  throw pappso::PappsoException(
+                    QObject::tr("Unable to create directory %1/%2. Check file "
+                                "system permissions")
+                      .arg(parent.canonicalPath())
+                      .arg(_project_sp.get()->getProjectName()));
+                }
+            }
         }
       if(filename.isEmpty())
         {
@@ -295,7 +354,8 @@ MainWindow::doAcceptedExportSpreadsheetDialog()
 
       showWaitingMessage(
         tr("writing %1 ODS file").arg(QFileInfo(filename).fileName()));
-      emit operateWritingOdsFile(filename, format, _project_sp);
+      emit operateWritingOdsFile(
+        filename, format, _project_sp, _p_export_spreadsheet_dialog);
       // emit operateXpipFile(filename);
     }
   catch(pappso::PappsoException &error)
@@ -316,6 +376,17 @@ MainWindow::doAcceptedTandemRunDialog()
   qDebug();
 }
 
+void
+MainWindow::doAcceptedSageRunDialog()
+{
+  qDebug();
+  showWaitingMessage(tr("Running Sage"));
+  qDebug();
+  emit operateRunningSage(mp_sageRunDialog->getSageRunBatch());
+  qDebug();
+}
+
+
 void
 MainWindow::doAcceptedLoadResultDialog()
 {
@@ -364,7 +435,7 @@ MainWindow::doLoadingResultsReady(ProjectSp project_sp)
   qDebug();
   if(_p_load_results_dialog != nullptr)
     {
-      _p_load_results_dialog->setProjectContaminants(project_sp.get());
+      //_p_load_results_dialog->setProjectContaminants(project_sp.get());
     }
   doProjectReady(project_sp);
   qDebug();
@@ -381,9 +452,9 @@ MainWindow::doProjectReady(ProjectSp project_sp)
 
   ui->menu_export_files->setDisabled(false);
   ui->actionMassChroQ->setDisabled(false);
-  ui->menuMCQR->setDisabled(false);
   ui->actionModifications->setDisabled(false);
   ui->actionLabeling_methods->setDisabled(false);
+  ui->actionSpectral_Count->setDisabled(false);
 
   // Create the alignment group with all the msrun within
   if(_project_sp->getAllMsRunAlignmentGroup() == nullptr)
@@ -397,44 +468,6 @@ MainWindow::doProjectReady(ProjectSp project_sp)
       _project_sp->setAllMsRunAlignmentGroup(all_msrun_group);
     }
 
-  // Check if the MCQR action can be enabled and add the corresponding actions
-  ui->menuAnalyze_one_group->clear();
-  ui->menu_XIC_analysis->clear();
-  for(MsRunAlignmentGroupSp align_group :
-      _project_sp->getMsRunAlignmentGroupList())
-    {
-      if(align_group->getGroupStatus() == AlignmentGroupStatus::masschroq_run)
-        {
-          ui->menuAnalyze_one_group->addAction(
-            align_group->getMsRunAlignmentGroupName());
-          bool already_exist = false;
-          for(QAction *action : ui->menu_XIC_analysis->actions())
-            {
-              if(action->text() ==
-                 QFileInfo(align_group->getMassChroqmlPath()).baseName())
-                {
-                  already_exist = true;
-                }
-            }
-          if(!already_exist)
-            {
-              qDebug() << align_group->getMassChroqmlPath();
-              ui->menu_XIC_analysis->addAction(
-                QFileInfo(align_group->getMassChroqmlPath()).baseName());
-            }
-        }
-    }
-  if(ui->menu_XIC_analysis->actions().size() > 0)
-    {
-      ui->menu_XIC_analysis->setEnabled(true);
-    }
-  else
-    {
-
-      ui->menu_XIC_analysis->addAction(getProjectSp().get()->getProjectName());
-      ui->menu_XIC_analysis->setEnabled(true);
-    }
-
   // Reset masschroq_run_dialog with new project
   if(_p_export_masschroq_dialog != nullptr)
     {
@@ -471,7 +504,9 @@ MainWindow::doActionModifications()
 void
 MainWindow::doProjectNotReady(QString error)
 {
+  hideWaitingMessage();
   viewError(error);
+  hideWaitingMessage();
 }
 
 
@@ -498,6 +533,32 @@ MainWindow::doActionTandemRun()
                   .arg(error.qwhat()));
     }
 }
+
+void
+MainWindow::doActionSageRun()
+{
+  try
+    {
+      if(mp_sageRunDialog == nullptr)
+        {
+          mp_sageRunDialog = new SageRunDialog(this);
+          connect(mp_sageRunDialog,
+                  &SageRunDialog::accepted,
+                  this,
+                  &MainWindow::doAcceptedSageRunDialog);
+        }
+      mp_sageRunDialog->show();
+      mp_sageRunDialog->raise();
+      mp_sageRunDialog->activateWindow();
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(
+        tr("Error opening Sage run dialog window :\n%1").arg(error.qwhat()));
+    }
+}
+
+
 void
 MainWindow::loadResults()
 {
@@ -523,6 +584,7 @@ MainWindow::showWaitingMessage(const QString title)
   qDebug();
   _p_waiting_message_dialog->setWindowTitle(title);
   qDebug();
+  _p_waiting_message_dialog->message("");
   _p_waiting_message_dialog->show();
   qDebug();
   _p_waiting_message_dialog->raise();
@@ -572,6 +634,10 @@ MainWindow::doActionSaveProject()
       QSettings settings;
       QString default_location = settings.value("path/xpipfile", "").toString();
 
+      if(_project_window != nullptr)
+        {
+          _project_sp.get()->setProjectName(_project_window->getProjectName());
+        }
 
       QString filename = QFileDialog::getSaveFileName(
         this,
@@ -600,6 +666,108 @@ MainWindow::doActionSaveProject()
     }
 }
 
+void
+MainWindow::doActionFann()
+{
+  qDebug();
+  try
+    {
+      QSettings settings;
+      QString default_location = settings.value("path/fann", "").toString();
+
+      QString filename = QFileDialog::getSaveFileName(
+        this,
+        tr("Save Fann data file"),
+        QString("%1/untitled.data").arg(default_location),
+        tr("data (*.data)"));
+
+      if(filename.isEmpty())
+        {
+          return;
+        }
+
+      settings.setValue("path/fann", QFileInfo(filename).absolutePath());
+
+      showWaitingMessage(
+        tr("Writing %1 Fann data file").arg(QFileInfo(filename).fileName()));
+      emit operateWritingFannDataFile(filename, _project_sp);
+      // emit operateXpipFile(filename);
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(
+        tr("Error while writing Fann data file :\n%1").arg(error.qwhat()));
+    }
+  qDebug();
+}
+
+void
+MainWindow::doActionMcqrSpectralCount()
+{
+  qDebug();
+
+  try
+    {
+      if(mp_mcqrScRun == nullptr)
+        {
+          mp_mcqrScRun = new McqrScRunView(this);
+        }
+      mp_mcqrScRun->show();
+      mp_mcqrScRun->raise();
+      mp_mcqrScRun->activateWindow();
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(tr("Error opening MCQR spectral count run dialog window :\n%1")
+                  .arg(error.qwhat()));
+    }
+}
+
+void
+MainWindow::doActionMcqrDev()
+{
+  qDebug();
+
+  try
+    {
+      if(mp_mcqrRun == nullptr)
+        {
+          mp_mcqrRun = new McqrRunViewNg(this);
+        }
+      mp_mcqrRun->show();
+      mp_mcqrRun->raise();
+      mp_mcqrRun->activateWindow();
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(
+        tr("Error opening MCQR run dialog window :\n%1").arg(error.qwhat()));
+    }
+}
+
+void
+MainWindow::doActionMsStats()
+{
+  qDebug();
+
+  try
+    {
+      if(mp_msstatsRun == nullptr)
+        {
+          mp_msstatsRun = new MsStatsRunView(this);
+        }
+      mp_msstatsRun->show();
+      mp_msstatsRun->raise();
+      mp_msstatsRun->activateWindow();
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(
+        tr("Error opening MSstats run dialog window :\n%1").arg(error.qwhat()));
+    }
+}
+
+
 void
 MainWindow::doActionSpreadsheet()
 {
@@ -621,48 +789,19 @@ MainWindow::doActionSpreadsheet()
   qDebug();
 }
 
-void
-MainWindow::doActionSpectralCountingMcq()
-{
-  qDebug();
-
-
-  qDebug();
-
-  QSettings settings;
-  QString default_location = settings.value("path/scmcqfile", "").toString();
-
-  QString filename = QFileDialog::getSaveFileName(
-    this,
-    tr("Save spectral count TSV file"),
-    QString("%1/untitled.tsv").arg(default_location),
-    tr("TSV (*.tsv)"));
-
-  if(filename.isEmpty())
-    {
-      return;
-    }
-
-  settings.setValue("path/scmcqfile", QFileInfo(filename).absolutePath());
-
-  showWaitingMessage(tr("Writing %1 spectral count file for MassChroqR")
-                       .arg(QFileInfo(filename).fileName()));
-  emit operateWritingMcqrSpectralCountFile(filename, _project_sp);
-
-  qDebug();
-}
-
 void
 MainWindow::doActionFasta()
 {
   QSettings settings;
   QString default_location = settings.value("path/fastafile", "").toString();
 
-  QString filename = QFileDialog::getSaveFileName(
-    this,
-    tr("Save FASTA file"),
-    QString("%1/untitled.fasta").arg(default_location),
-    tr("FASTA (*.fasta)"));
+  QString filename =
+    QFileDialog::getSaveFileName(this,
+                                 tr("Save FASTA file"),
+                                 QString("%1/%2.fasta")
+                                   .arg(default_location)
+                                   .arg(_project_sp.get()->getProjectName()),
+                                 tr("FASTA (*.fasta)"));
 
   if(filename.isEmpty())
     {
@@ -677,17 +816,46 @@ MainWindow::doActionFasta()
 }
 
 
+void
+MainWindow::doActionFastaAllValidTargetProteins()
+{
+  QSettings settings;
+  QString default_location = settings.value("path/fastafile", "").toString();
+
+  QString filename =
+    QFileDialog::getSaveFileName(this,
+                                 tr("Save FASTA file"),
+                                 QString("%1/%2.fasta")
+                                   .arg(default_location)
+                                   .arg(_project_sp.get()->getProjectName()),
+                                 tr("FASTA (*.fasta)"));
+
+  if(filename.isEmpty())
+    {
+      return;
+    }
+
+  settings.setValue("path/fastafile", QFileInfo(filename).absolutePath());
+
+  showWaitingMessage(
+    tr("Writing %1 FASTA file").arg(QFileInfo(filename).fileName()));
+  emit operateWritingFastaFile(
+    filename, _project_sp, ExportFastaType::allValidTargetProteins);
+}
+
 void
 MainWindow::doActionFastaOneBySubgroup()
 {
   QSettings settings;
   QString default_location = settings.value("path/fastafile", "").toString();
 
-  QString filename = QFileDialog::getSaveFileName(
-    this,
-    tr("Save FASTA file"),
-    QString("%1/untitled.fasta").arg(default_location),
-    tr("FASTA (*.fasta)"));
+  QString filename =
+    QFileDialog::getSaveFileName(this,
+                                 tr("Save FASTA file"),
+                                 QString("%1/%2.fasta")
+                                   .arg(default_location)
+                                   .arg(_project_sp.get()->getProjectName()),
+                                 tr("FASTA (*.fasta)"));
 
   if(filename.isEmpty())
     {
@@ -708,11 +876,13 @@ MainWindow::doActionFastaOneByGroup()
   QSettings settings;
   QString default_location = settings.value("path/fastafile", "").toString();
 
-  QString filename = QFileDialog::getSaveFileName(
-    this,
-    tr("Save FASTA file"),
-    QString("%1/untitled.fasta").arg(default_location),
-    tr("FASTA (*.fasta)"));
+  QString filename =
+    QFileDialog::getSaveFileName(this,
+                                 tr("Save FASTA file"),
+                                 QString("%1/%2.fasta")
+                                   .arg(default_location)
+                                   .arg(_project_sp.get()->getProjectName()),
+                                 tr("FASTA (*.fasta)"));
 
   if(filename.isEmpty())
     {
@@ -727,6 +897,7 @@ MainWindow::doActionFastaOneByGroup()
     filename, _project_sp, ExportFastaType::oneByGroup);
 }
 
+
 void
 MainWindow::doActionMassChroQ()
 {
@@ -757,57 +928,6 @@ MainWindow::doActionMassChroQ()
   qDebug();
 }
 
-void
-MainWindow::doActionScMcqr()
-{
-  qDebug() << "Run SC analysis";
-  try
-    {
-      if(mp_mcqrParamAllQuantiDialog != nullptr)
-        {
-          delete mp_mcqrParamAllQuantiDialog;
-          mp_mcqrParamAllQuantiDialog = nullptr;
-        }
-      mp_mcqrParamAllQuantiDialog =
-        new McqrParamAllQuantiDialog(this, _project_sp);
-      mp_mcqrParamAllQuantiDialog->show();
-      mp_mcqrParamAllQuantiDialog->raise();
-      mp_mcqrParamAllQuantiDialog->activateWindow();
-    }
-  catch(pappso::PappsoException &error)
-    {
-      viewError(tr("Error while running MCQR parameter window :\n%1")
-                  .arg(error.qwhat()));
-    }
-}
-
-void
-MainWindow::doActionXicMcqr(QAction *action)
-{
-  qDebug() << "begin";
-  if(action != nullptr)
-    {
-      try
-        {
-          if(mp_mcqrParamAllQuantiDialog != nullptr)
-            {
-              delete mp_mcqrParamAllQuantiDialog;
-              mp_mcqrParamAllQuantiDialog = nullptr;
-            }
-          mp_mcqrParamAllQuantiDialog =
-            new McqrParamAllQuantiDialog(this, _project_sp, action->text());
-          mp_mcqrParamAllQuantiDialog->show();
-          mp_mcqrParamAllQuantiDialog->raise();
-          mp_mcqrParamAllQuantiDialog->activateWindow();
-        }
-      catch(pappso::PappsoException &error)
-        {
-          viewError(tr("Error while running MCQR parameter window :\n%1")
-                      .arg(error.qwhat()));
-        }
-    }
-  qDebug() << "end";
-}
 
 void
 MainWindow::doActionOneGroupMcqr(QAction *action_group)
@@ -824,13 +944,6 @@ MainWindow::doActionOneGroupMcqr(QAction *action_group)
     }
 }
 
-void
-MainWindow::doCloseMcqrRunView()
-{
-  qDebug() << "ask to close McqrRunView";
-  delete mp_mcqrRunView;
-}
-
 void
 MainWindow::doAcceptedMassChroqRunDialog()
 {
@@ -838,8 +951,6 @@ MainWindow::doAcceptedMassChroqRunDialog()
   try
     {
 
-      _p_export_masschroq_dialog->updateMasschroqFileParameters();
-
       _project_sp.get()->getMasschroqFileParametersSp().get()->save();
       qDebug() << _project_sp.get()
                     ->getMasschroqFileParametersSp()
@@ -850,11 +961,11 @@ MainWindow::doAcceptedMassChroqRunDialog()
 
       QString filename =
         QFileDialog::getSaveFileName(this,
-                                     tr("Save MassChroqML file"),
-                                     tr("%1/%2.masschroqml")
+                                     tr("Save MassChroq JSON file"),
+                                     tr("%1/%2.json")
                                        .arg(default_location)
                                        .arg(_project_sp->getProjectName()),
-                                     tr("MassChroqML (*.masschroqml)"));
+                                     tr("MassChroQ JSON (*.json)"));
 
       if(filename.isEmpty())
         {
@@ -876,99 +987,11 @@ MainWindow::doAcceptedMassChroqRunDialog()
   qDebug();
 }
 
-void
-MainWindow::doAcceptedMcqrParamAllQuantiDialog()
-{
-  qDebug();
-
-  qDebug() << "begin";
-  try
-    {
-      QSettings settings;
-      McqrExperimentSp mcqr_experiment =
-        _project_sp.get()->getMcqrExperimentSp();
-      mcqr_experiment.get()->setMcqrExperimentType(
-        McqrExperimentType::spectralCount);
-
-      if(mp_mcqrParamAllQuantiDialog->getMassChroqResultsUsed())
-        { // XIC
-
-          mcqr_experiment.get()->setMcqrExperimentType(McqrExperimentType::xic);
-          if(mp_mcqrParamAllQuantiDialog->getMcqrRunStatus())
-            {
-
-              mcqr_experiment.get()->setMetadataOdsFilePath(
-                mp_mcqrParamAllQuantiDialog->getMetadataOdsFileInfo()
-                  .absoluteFilePath());
-              mcqr_experiment.get()->setMcqrWorkingDirectory(
-                mp_mcqrParamAllQuantiDialog->getMetadataOdsFileInfo()
-                  .absolutePath());
-
-              mp_mcqrRunView = new McqrRunView(this, mcqr_experiment);
-              mp_mcqrRunView->show();
-              mp_mcqrRunView->raise();
-              mp_mcqrRunView->activateWindow();
-              qDebug() << "Run Mcqr!!";
-            }
-        }
-      else
-        { // spectral count
-          QString default_location =
-            settings.value("mcqr/rdata_path").toString();
-          QString rdata_path =
-            QFileDialog::getSaveFileName(this,
-                                         tr("save RData file"),
-                                         tr("%1/%2.RData")
-                                           .arg(default_location)
-                                           .arg(_project_sp->getProjectName()),
-                                         tr("RData files ( *.RData)"));
-
-
-          if(!rdata_path.isEmpty())
-            {
-
-              mcqr_experiment.get()->setRdataFilePath(
-                QFileInfo(rdata_path).absoluteFilePath());
-
-              mcqr_experiment.get()->setMcqrWorkingDirectory(
-                QFileInfo(rdata_path).absolutePath());
-              showWaitingMessage(tr("Writing %1 RData file").arg(rdata_path));
-              settings.setValue("mcqr/rdata_path",
-                                mcqr_experiment.get()->getRdataFilePath());
-
-              emit operateWritingMcqrSpectralCountRdata(mcqr_experiment,
-                                                        _project_sp);
-            }
-        }
-    }
-  catch(pappso::PappsoException &error)
-    {
-      viewError(
-        tr("Error while writing Mcqr RData file:\n%1").arg(error.qwhat()));
-    }
-}
-
-void
-MainWindow::doWritingMcqrSpectralCountRdataFinished(
-  McqrExperimentSp p_mcqr_experiment)
-{
-  qDebug() << "RData file created";
-  hideWaitingMessage();
-  if(mp_mcqrParamAllQuantiDialog->getMcqrRunStatus())
-    {
-      mp_mcqrRunView = new McqrRunView(this, p_mcqr_experiment);
-      mp_mcqrRunView->show();
-      mp_mcqrRunView->raise();
-      mp_mcqrRunView->activateWindow();
-      qDebug() << "Run Mcqr!!";
-    }
-}
-
 
 void
 MainWindow::doWritingMassChroQmlFileFinished(
   QString masschroqml_file,
-  std::vector<MsRunAlignmentGroupSp> quantified_groups)
+  std::vector<MsRunAlignmentGroupSp> quantified_groups [[maybe_unused]])
 {
   qDebug() << "MassChroQml created";
   if(_p_export_masschroq_dialog->getMassChroqRunStatus())
@@ -977,14 +1000,6 @@ MainWindow::doWritingMassChroQmlFileFinished(
       showWaitingMessage(tr("Running MassChroQ"));
       emit operateRunningMassChroq(
         _p_export_masschroq_dialog->getMassChroqRunBatchParam());
-      ui->menu_XIC_analysis->addAction(QFileInfo(masschroqml_file).baseName());
-      ui->menu_XIC_analysis->setEnabled(true);
-      for(MsRunAlignmentGroupSp group : quantified_groups)
-        {
-          ui->menuAnalyze_one_group->addAction(
-            group->getMsRunAlignmentGroupName());
-        }
-      ui->menuMCQR->setDisabled(false);
     }
   _p_export_masschroq_dialog->updateAlignmentGroupsStatus(masschroqml_file);
   _project_window->projectStatusChanged();
@@ -1005,7 +1020,9 @@ MainWindow::doActionMassChroqPRM()
       QString filename = QFileDialog::getSaveFileName(
         this,
         tr("Save MassChroqPRM file"),
-        QString("%1/untitled.masschroqprm").arg(default_location),
+        QString("%1/%2.masschroqprm")
+          .arg(default_location)
+          .arg(_project_sp.get()->getProjectName()),
         tr("MassChroqPRM (*.masschroqprm)"));
 
       if(filename.isEmpty())
@@ -1043,7 +1060,9 @@ MainWindow::doActionProticDb()
       QString filename = QFileDialog::getSaveFileName(
         this,
         tr("Save PROTICdbML file"),
-        QString("%1/untitled.proticdbml").arg(default_location),
+        QString("%1/%2.proticdbml")
+          .arg(default_location)
+          .arg(_project_sp.get()->getProjectName()),
         tr("PROTICdbML (*.proticdbml)"));
 
       if(filename.isEmpty())
@@ -1115,7 +1134,7 @@ MainWindow::doCheckNewVersion()
         tr("Download version %1").arg(m_onlineVersion.getVersion()),
         QMessageBox::AcceptRole);
       version_message_box->addButton(
-        tr("Keep version %1").arg(m_onlineVersion.getVersion()),
+        tr("Keep version %1").arg(QStringLiteral(i2MassChroQ_VERSION)),
         QMessageBox::RejectRole);
 
       version_message_box->exec();
@@ -1140,7 +1159,7 @@ MainWindow::run()
 
   try
     {
-      qDebug();
+      qWarning() << qApp->applicationDirPath();
       QCommandLineParser parser;
 
       // throw pappso::PappsoException("test");
@@ -1168,15 +1187,13 @@ MainWindow::run()
   catch(pappso::PappsoException &error)
     {
       viewError(
-        tr("An error occurred in i2MassChroQ. Error :\n%1")
-          .arg(error.qwhat()));
+        tr("An error occurred in i2MassChroQ. Error :\n%1").arg(error.qwhat()));
     }
 
   catch(std::exception &error)
     {
       viewError(
-        tr("An error occurred in i2MassChroQ. Error :\n%1")
-          .arg(error.what()));
+        tr("An error occurred in i2MassChroQ. Error :\n%1").arg(error.what()));
     }
 }
 
