@@ -29,10 +29,10 @@
  ******************************************************************************/
 
 #include "proticdbml.h"
-#include <pappsomspp/pappsoexception.h>
-#include <pappsomspp/utils.h>
-#include <pappsomspp/grouping/grpprotein.h>
-#include <pappsomspp/amino_acid/aa.h>
+#include <pappsomspp/core/pappsoexception.h>
+#include <pappsomspp/core/utils.h>
+#include <pappsomspp/core/grouping/grpprotein.h>
+#include <pappsomspp/core/amino_acid/aa.h>
 #include "../core/msrun.h"
 #include "../config.h"
 #include "../utils/utils.h"
