@@ -33,9 +33,9 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QDir>
-#include <pappsomspp/pappsoexception.h>
-#include <pappsomspp/exception/exceptionnotfound.h>
-#include <pappsomspp/utils.h>
+#include <pappsomspp/core/pappsoexception.h>
+#include <pappsomspp/core/exception/exceptionnotfound.h>
+#include <pappsomspp/core/utils.h>
 #include "../config.h"
 
 Xpip::Xpip(const QString &out_filename)
@@ -93,7 +93,8 @@ Xpip::write(ProjectSp sp_project)
   _output_stream->writeNamespace("http://www.w3.org/2001/XMLSchema-instance",
                                  "xsi");
   //_output_stream->writeNamespace("http://www.w3.org/2001/XMLSchema-instance","xsi");
-  _output_stream->writeAttribute("xmlns", "http://pappso.inra.fr/xsd/xpip/4.0");
+  _output_stream->writeAttribute("xmlns",
+                                 "http://pappso.inrae.fr/xsd/xpip/4.0");
   // xsi:schemaLocation="http://psidev.info/psi/pi/mzIdentML/1.1
   // http://www.psidev.info/files/mzIdentML1.1.0.xsd"
   _output_stream->writeAttribute("http://www.w3.org/2001/XMLSchema-instance",
@@ -121,30 +122,50 @@ Xpip::write(ProjectSp sp_project)
     "mode",
     QString("%1").arg(
       (std::int8_t)_sp_project.get()->getContaminantRemovalMode()));
-  std::vector<const FastaFile *> conta_file_list =
-    _sp_project.get()->getProteinStore().getContaminantFastaFileList();
-  _output_stream->writeAttribute(
-    "regexp",
-    _sp_project.get()->getProteinStore().getRegexpContaminant().pattern());
-  QStringList fasta_list;
-  for(const FastaFile *fasta_file : conta_file_list)
+
+  if(_sp_project.get()->getProteinStore().getContaminantSelectionType() ==
+     ContaminantSelectionType::fastaFiles)
     {
-      fasta_list << fasta_file->getXmlId();
+      std::vector<const FastaFile *> conta_file_list =
+        _sp_project.get()->getProteinStore().getContaminantFastaFileList();
+      QStringList fasta_list;
+      for(const FastaFile *fasta_file : conta_file_list)
+        {
+          fasta_list << fasta_file->getXmlId();
+        }
+      _output_stream->writeAttribute("fasta_id", fasta_list.join(" "));
+    }
+  if(_sp_project.get()->getProteinStore().getContaminantSelectionType() ==
+     ContaminantSelectionType::regexp)
+    {
+      _output_stream->writeAttribute(
+        "regexp",
+        _sp_project.get()->getProteinStore().getRegexpContaminant().pattern());
     }
-  _output_stream->writeAttribute("fasta_id", fasta_list.join(" "));
   _output_stream->writeEndElement();
 
   _output_stream->writeStartElement("decoys");
-  std::vector<const FastaFile *> decoy_file_list =
-    _sp_project.get()->getProteinStore().getDecoyFastaFileList();
-  _output_stream->writeAttribute(
-    "regexp", _sp_project.get()->getProteinStore().getRegexpDecoy().pattern());
-  QStringList fasta_conta_list;
-  for(const FastaFile *fasta_file : conta_file_list)
+  if(_sp_project.get()->getProteinStore().getDecoySelectionType() ==
+     DecoySelectionType::regexp)
     {
-      fasta_conta_list << fasta_file->getXmlId();
+      _output_stream->writeAttribute(
+        "regexp",
+        _sp_project.get()->getProteinStore().getRegexpDecoy().pattern());
+    }
+  if(_sp_project.get()->getProteinStore().getDecoySelectionType() ==
+     DecoySelectionType::fastaFiles)
+    {
+      QStringList fasta_decoy_list;
+
+      std::vector<const FastaFile *> decoy_file_list =
+        _sp_project.get()->getProteinStore().getDecoyFastaFileList();
+
+      for(const FastaFile *fasta_file : decoy_file_list)
+        {
+          fasta_decoy_list << fasta_file->getXmlId();
+        }
+      _output_stream->writeAttribute("fasta_id", fasta_decoy_list.join(" "));
     }
-  _output_stream->writeAttribute("fasta_id", fasta_conta_list.join(" "));
   _output_stream->writeEndElement();
 
   writeMsrunList(_sp_project.get()->getMsRunStore());
@@ -195,8 +216,13 @@ Xpip::writeFilterParameters(const AutomaticFilterParameters &filters)
 {
   qDebug() << "Xpip::writeFilterParameters begin";
   _output_stream->writeStartElement("filter_params");
+  writeDoubleAttribute("type", (std::int8_t)filters.getAutomaticFilterType());
+  writeDoubleAttribute("fdr", filters.getFilterPeptideFDR());
+  writeDoubleAttribute("svm_prob", filters.getSvmprobThreshold());
+  writeDoubleAttribute("prot_prob", filters.getProteinSvmprobThreshold());
   writeDoubleAttribute("pep_evalue", filters.getFilterPeptideEvalue());
   writeDoubleAttribute("prot_evalue", filters.getFilterProteinEvalue());
+  writeDoubleAttribute("prot_qvalue", filters.getFilterProteinQvalue());
   _output_stream->writeAttribute(
     "pep_number", QString("%1").arg(filters.getFilterMinimumPeptidePerMatch()));
   writeBooleanAttribute("cross_sample",
@@ -273,7 +299,7 @@ Xpip::writeIdentificationDataSourceList(
 {
 
   _output_stream->writeStartElement("identification_source_list");
-  for(const IdentificationDataSourceSp ident_source_sp :
+  for(const IdentificationDataSourceSp &ident_source_sp :
       ident_store.getIdentificationDataSourceList())
     {
       _output_stream->writeStartElement("identification_source");
@@ -329,6 +355,10 @@ Xpip::writeIdentificationDataSourceList(
               _output_stream->writeAttribute(
                 "key",
                 QString("%1").arg(static_cast<std::int8_t>(stat_pair.first)));
+
+              qDebug() << stat_pair.second << " "
+                       << stat_pair.second.toString();
+
               _output_stream->writeAttribute("value",
                                              stat_pair.second.toString());
               _output_stream->writeEndElement();
@@ -345,14 +375,14 @@ Xpip::writeMsrunList(const MsRunStore &msrun_store)
 {
 
   _output_stream->writeStartElement("msrun_list");
-  for(const MsRunSp msrun_sp : msrun_store.getMsRunList())
+  for(const MsRunSp &msrun_sp : msrun_store.getMsRunList())
     {
       _output_stream->writeStartElement("msrun");
       _output_stream->writeAttribute("id", msrun_sp.get()->getXmlId());
       _output_stream->writeAttribute("name", msrun_sp.get()->getSampleName());
       _output_stream->writeAttribute("format",
                                      QString("%1").arg(static_cast<std::int8_t>(
-                                       msrun_sp.get()->getMzFormat())));
+                                       msrun_sp.get()->getMsDataFormat())));
       QFileInfo mz_info(msrun_sp.get()->getFileName());
       if(mz_info.exists())
         {
@@ -409,7 +439,8 @@ Xpip::writeMsrunAlignmentGroup(const MsRunAlignmentGroupSp alignment_group,
 
   // List of msruns in the group
   _output_stream->writeStartElement("msruns");
-  for(const MsRunSp ms_run : alignment_group.get()->getMsRunsInAlignmentGroup())
+  for(const MsRunSp &ms_run :
+      alignment_group.get()->getMsRunsInAlignmentGroup())
     {
       _output_stream->writeStartElement("grouped_msrun");
       _output_stream->writeAttribute("id", ms_run.get()->getXmlId());
@@ -438,46 +469,52 @@ Xpip::writeAlignmentGroupParameters(const MsRunAlignmentGroupSp alignment_group)
   // Alignment parameters
   _output_stream->writeStartElement("alignment_params");
   _output_stream->writeAttribute(
-    "ms2_tendency", QString::number(mcq_file_params.ms2_tendency_half_window));
+    "ms2_tendency",
+    QString::number(mcq_file_params.m_alignmentMethod.getMs2TendencyWindow()));
   _output_stream->writeAttribute(
     "ms2_smoothing",
-    QString::number(mcq_file_params.ms2_smoothing_half_window));
+    QString::number(mcq_file_params.m_alignmentMethod.getMs2SmoothingWindow()));
   _output_stream->writeAttribute(
     "ms1_smoothing",
-    QString::number(mcq_file_params.ms1_smoothing_half_window));
-  if(mcq_file_params.write_alignment_times)
-    {
-      _output_stream->writeAttribute("time_corrections",
-                                     mcq_file_params.alignment_times_directory);
-    }
-  else
-    {
-      _output_stream->writeAttribute("time_corrections", "");
-    }
+    QString::number(mcq_file_params.m_alignmentMethod.getMs1SmoothingWindow()));
   _output_stream->writeEndElement();
 
   // Quantification parameters
   _output_stream->writeStartElement("quanti_params");
   _output_stream->writeAttribute(
-    "xic_range", mcq_file_params.xic_extraction_range->toString());
+    "xic_range",
+    mcq_file_params.m_quantificationMethod.getXicExtractionUppersPrecisionPtr()
+      ->toString());
   _output_stream->writeAttribute(
     "xic_method",
-    QString::number((std::int8_t)mcq_file_params.xic_extraction_method));
+    QString::number((std::int8_t)mcq_file_params.m_quantificationMethod
+                      .getXicExtractMethod()));
+
+  const pappso::TraceDetectionZivy *detection_zivy =
+    dynamic_cast<const pappso::TraceDetectionZivy *>(
+      mcq_file_params.m_quantificationMethod.getTraceDetectionInterfaceCstSPtr()
+        .get());
+
+  if(detection_zivy == nullptr)
+    {
+      throw pappso::PappsoException(
+        "m_quantificationMethod.getTraceDetectionInterfaceCstSPtr().get() == "
+        "nullptr");
+    }
+
   _output_stream->writeAttribute(
     "smoothing",
-    QString::number(mcq_file_params.m_zivyParams._smoothing_half_window));
+    QString::number(detection_zivy->getSmoothingHalfEdgeWindows()));
   _output_stream->writeAttribute(
-    "minmax_half",
-    QString::number(mcq_file_params.m_zivyParams._minmax_half_window));
+    "minmax_half", QString::number(detection_zivy->getMinMaxHalfEdgeWindows()));
   _output_stream->writeAttribute(
-    "maxmin_half",
-    QString::number(mcq_file_params.m_zivyParams._maxmin_half_window));
+    "maxmin_half", QString::number(detection_zivy->getMaxMinHalfEdgeWindows()));
   _output_stream->writeAttribute(
     "minmax_thre",
-    QString::number(mcq_file_params.m_zivyParams._minmax_threshold));
+    QString::number(detection_zivy->getDetectionThresholdOnMinmax()));
   _output_stream->writeAttribute(
     "maxmin_thre",
-    QString::number(mcq_file_params.m_zivyParams._maxmin_threshold));
+    QString::number(detection_zivy->getDetectionThresholdOnMaxmin()));
   _output_stream->writeEndElement();
 
   // Masschroq parameters
@@ -498,10 +535,6 @@ Xpip::writeAlignmentGroupParameters(const MsRunAlignmentGroupSp alignment_group)
       compar_path = dir_path + "/compar_" + file_name + ".tsv";
     }
   _output_stream->writeAttribute("result", result_path);
-  if(mcq_file_params.export_compar_file)
-    {
-      _output_stream->writeAttribute("compar", compar_path);
-    }
   _output_stream->writeEndElement();
 }
 
@@ -578,6 +611,8 @@ Xpip::writeProteinList()
             QString("%1").arg(static_cast<std::int8_t>(db_xref.database)));
           _output_stream->writeEndElement();
         }
+
+
       _output_stream->writeEndElement();
     }
   _output_stream->writeEndElement();
@@ -608,7 +643,7 @@ Xpip::writeLabelingMethod()
     {
       _output_stream->writeStartElement("label");
       _output_stream->writeAttribute("id", p_label->getXmlId());
-      for(const LabelModification label_modification :
+      for(const LabelModification &label_modification :
           p_label->getLabelModifictionList())
         {
           _output_stream->writeStartElement("label_modification");
@@ -658,7 +693,8 @@ Xpip::writePeptideList()
       _map_peptides.insert(
         std::pair<const PeptideXtp *, QString>(p_peptide, idp));
       _output_stream->writeAttribute("id", idp);
-      _output_stream->writeAttribute("seq", p_peptide->getSequence());
+      _output_stream->writeAttribute("proforma", p_peptide->toProForma());
+
 
       const Label *p_label = p_peptide->getLabel();
       if(p_label != nullptr)
@@ -667,31 +703,6 @@ Xpip::writePeptideList()
         }
 
 
-      unsigned int i = 0;
-      for(const pappso::Aa &amino_acid : *p_peptide)
-        {
-
-          std::vector<pappso::AaModificationP> aa_modif_list =
-            amino_acid.getModificationList();
-
-
-          for(auto &&aa_modif : aa_modif_list)
-            {
-              if(!aa_modif->isInternal())
-                {
-                  _output_stream->writeStartElement("mod");
-                  _output_stream->writeAttribute(
-                    "ref", _map_modifications.at(aa_modif));
-                  _output_stream->writeAttribute("position",
-                                                 QString("%1").arg(i));
-                  _output_stream->writeAttribute(
-                    "aa", QString(amino_acid.getLetter()));
-                  _output_stream->writeEndElement(); // mod
-                }
-            }
-          i++;
-        }
-
       _output_stream->writeEndElement(); // peptide
     }
   _output_stream->writeEndElement(); // peptide_list
@@ -843,6 +854,28 @@ Xpip::writeIdentificationGroup(
         {
           _output_stream->writeAttribute("checked", "false");
         }
+
+      qDebug() << "getParamList";
+      const std::map<ProteinParam, QVariant> &params =
+        p_protein_match->getParamList();
+
+      // if (params.size() > 0) {
+      //   _output_stream->writeStartElement("stats");
+      if(params.size() > 0)
+        {
+          _output_stream->writeStartElement("params");
+          for(const std::pair<ProteinParam, QVariant> param_pair : params)
+            {
+              _output_stream->writeStartElement("param");
+              _output_stream->writeAttribute(
+                "key",
+                QString("%1").arg(static_cast<std::int8_t>(param_pair.first)));
+              _output_stream->writeAttribute("value",
+                                             param_pair.second.toString());
+              _output_stream->writeEndElement();
+            }
+          _output_stream->writeEndElement();
+        }
       for(const PeptideMatch &peptide_match :
           p_protein_match->getPeptideMatchList())
         {
